**Pymatsci**  (Python Materials Science) is a robust, open-source Python library for materials analysis. It is further packaged and developed on the basis of **Pymatgen**, a very powerful package of material analysis. Pymatsci is dedicated to quick and easy operations, so that people can get the results they want without taking too much time.
More detailed information can refer to the `wiki`_.

.. _wiki: https://pymatsci.readthedocs.io/en/latest/